package CGI::Untaint::countrycode;
use warnings;
use strict;
use base 'CGI::Untaint::country';
1;
